@@ -8,18 +8,18 @@
 #'
 #'
 print.cpgeeSWD <- function(x, ...) {
-  
+
     p = length(x$beta)
     q = length(x$alpha)
-    
+
     niter = x$niter
     outbeta = x$outbeta
     outalpha = x$outalpha
 
-    cat("GEE and MAEE for Cluster-Period Summaries","\n",
-        "Number of Iterations:", niter,"\n")
-
+    cat("GEE and MAEE for Cluster-Period Summaries", "\n", "Number of Iterations:", 
+        niter, "\n")
 
+    
     cat("Results for marginal mean parameters \n")
     print(outbeta)
     cat("\n")
