@@ -9,17 +9,17 @@
 #'
 #'
 print.geemaee <- function(x, ...) {
-  
+
     p = length(x$beta)
     q = length(x$alpha)
     niter = x$niter
     outbeta = x$outbeta
     outalpha = x$outalpha
 
-    cat("GEE for correlated Gaussian data","\n",
-        "Number of Iterations:",niter,"\n")
-
+    cat("GEE for correlated Gaussian data", "\n", "Number of Iterations:", 
+        niter, "\n")
 
+    
     cat("Results for marginal mean parameters \n")
     print(outbeta)
     cat("\n")
